@@ -83,6 +83,7 @@ class ExDbWorkflow(object):
             logger.exception("Argument or configuration processing failing with %s", str(e))
             return False
         #
+        okS = ok = False
         if dbType == "mongo":
             if op == "etl_tree_node_lists":
                 rhw = TreeNodeListWorker(
@@ -136,13 +137,7 @@ class ExDbWorkflow(object):
                     refChunkSize=refChunkSize,
                 )
                 okS = ok
-            elif op in ["refresh_pubchem"]:
-                # Note kwargs  - 'loadType='replace' to replace to add to existing object store or 'full' to ignore current data.
-                #                'rebuildChemIndices=True' to recreated chem comp and search source indices.
-                #                Caution with numProc as the Pubchem API is throttled
-                crw = ChemRefEtlWorker(self.__cfgOb, self.__cachePath, numProc=numProc, chunkSize=chunkSize, useCache=self.__useCache)
-                ok = crw.refresh(extResource="PubChem", **kwargs)
-                okS = ok
+
         #
         logger.info("Completed operation %r with status %r\n", op, ok and okS)
         return ok and okS
